use axum::{Form, Router};
use axum::extract::{Path, Query};
use axum::routing::get;

use crate::{form, view};
use crate::common::{response::HtmlResponse, Result};
use crate::common::response::{redirect, RedirectResponse};
use crate::common::template::render;
use crate::param::{CategoryParams, DelParams};
use crate::service::category::CategoryService;

pub fn init_router() -> Router {
    Router::new()
        .route("/", get(index))
        .route(
            "/add",
            get(add_ui).post(add),
        )
        .route(
            "/edit/:id",
            get(edit_ui).post(edit),
        )
        .route("/del/:id", get(del))
        .route("/del/:id/:real", get(del))
        .route("/articles/:id", get(articles))
}

pub async fn index(Query(params): Query<CategoryParams>) -> Result<HtmlResponse> {
    let handler_name = "category/index";
    let tpl = CategoryService::index(handler_name, params).await?;
    render(tpl, handler_name)
}


pub async fn find(Path(id): Path<u32>) -> Result<String> {
    let handler_name = "category/find";
    let category_model = CategoryService::find(handler_name, id).await?;
    Ok(format!("id: {}, 名称: {}", category_model.id, category_model.name))
}

pub async fn add_ui() -> Result<HtmlResponse> {
    let handler_name = "category/add_ui";
    let tpl = view::CategoryAddTemplate;
    render(tpl, handler_name)
}

pub async fn add(Form(frm): Form<form::CategoryForm>) -> Result<RedirectResponse> {
    let handler_name = "category/add";
    let added_category_id = CategoryService::add(handler_name, frm).await?;
    let url = format!("/category?msg=分类添加成功，ID是：{}", added_category_id);
    redirect(url.as_str())
}

pub async fn edit_ui(Path(id): Path<u32>) -> Result<HtmlResponse> {
    let handler_name = "category/edit_ui";
    let tpl = CategoryService::edit_ui(handler_name, id).await?;
    render(tpl, handler_name)
}

pub async fn edit(
    Path(id): Path<u32>,
    Form(frm): Form<form::CategoryForm>,
) -> Result<RedirectResponse> {
    let handler_name = "category/edit";
    CategoryService::edit(handler_name, id, frm).await?;
    redirect("/category?msg=分类修改成功")
}


pub async fn del(Path(params): Path<DelParams>) -> Result<RedirectResponse> {
    let handler_name = "category/del";
    CategoryService::del(handler_name, params).await?;
    redirect("/category?msg=分类删除成功")
}

pub async fn articles(Path(id): Path<u32>, Query(params): Query<CategoryParams>) -> Result<HtmlResponse> {
    let handler_name = "category/articles";
    let tpl = CategoryService::articles(handler_name, id, params).await?;
    render(tpl, handler_name)
}