use std::env;

use config::File;

use crate::APPLICATION_CONTEXT;
use crate::config::app::AppConfig;

/// 初始化配置信息
pub async fn init_config() {
    let run_mode = env::var("RUN_MODE").unwrap_or_else(|_| "dev".into());

    // https://github.com/mehcode/config-rs/blob/master/examples/hierarchical-env/settings.rs
    let config: AppConfig = config::Config::builder()
        // Start off by merging in the "default" configuration file
        .add_source(File::with_name("config/default"))
        // Add in the current environment file
        // Default to 'dev' env
        // Note that this file is _optional_
        .add_source(
            File::with_name(&format!("config/{}", run_mode)).required(false),
        )
        .build()
        .map_err(|e| tracing::error!("config build failed: {}", e.to_string()))
        .unwrap()
        .try_deserialize()
        .map_err(|e| tracing::error!("config init failed: {}", e.to_string()))
        .unwrap();

    APPLICATION_CONTEXT.set::<AppConfig>(config);
}